==> pymovements-0.8.0.tar.gz: pymovements-0.8.0/src/pymovements/__init__.py <==
# Copyright (c) 2022-2023 The pymovements Project Authors
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""This module provides access to all submodules."""
from pymovements import datasets  # noqa: F401
from pymovements import events  # noqa: F401
from pymovements import gaze  # noqa: F401
from pymovements import plotting  # noqa: F401
from pymovements import synthetic  # noqa: F401
from pymovements import utils  # noqa: F401
from pymovements.datasets import Dataset  # noqa: F401
from pymovements.datasets import PublicDataset  # noqa: F401
from pymovements.datasets import PublicDatasetDefinition  # noqa: F401

==> pymovements-0.9.0.tar.gz: pymovements-0.9.0/src/pymovements/__init__.py <==
# Copyright (c) 2022-2023 The pymovements Project Authors
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""This module provides access to all submodules."""
from pymovements import datasets  # noqa: F401
from pymovements import events  # noqa: F401
from pymovements import gaze  # noqa: F401
from pymovements import plotting  # noqa: F401
from pymovements import synthetic  # noqa: F401
from pymovements import utils  # noqa: F401
from pymovements.dataset import Dataset  # noqa: F401
from pymovements.dataset import DatasetDefinition  # noqa: F401
from pymovements.dataset import DatasetLibrary  # noqa: F401
from pymovements.dataset import DatasetPaths  # noqa: F401
from pymovements.dataset import register_dataset  # noqa: F401
from pymovements.gaze.experiment import Experiment  # noqa: F401
from pymovements.gaze.screen import Screen  # noqa: F401
